@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #go install mover.go && 
-env GOOS=darwin GOARCH=amd64 go build -o copyfil mover.go
+env GOOS=darwin GOARCH=amd64 go build -o plmo mover.go
 FROM=/Users/hesdx/Documents/ipfs/plotman/copyop/temp
 TO=/Users/hesdx/Documents/ipfs/plotman/copyop/dst/
 
-./copyfil $FROM $TO 10010001 farmm.log
\ No newline at end of file
+./plmo $FROM $TO 10010001 farming.log
\ No newline at end of file
